@@ -9,19 +9,7 @@
 -- By Gerald Combs <gerald@wireshark.org>
 -- Copyright 1998 Gerald Combs
 --
--- This program is free software; you can redistribute it and/or
--- modify it under the terms of the GNU General Public License
--- as published by the Free Software Foundation; either version 2
--- of the License, or (at your option) any later version.
---
--- This program is distributed in the hope that it will be useful,
--- but WITHOUT ANY WARRANTY; without even the implied warranty of
--- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
--- GNU General Public License for more details.
---
--- You should have received a copy of the GNU General Public License
--- along with this program; if not, write to the Free Software
--- Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+-- SPDX-License-Identifier: GPL-2.0-or-later
 
 -- Set disable_lua to true to disable Lua support.
 disable_lua = false
@@ -310,7 +298,8 @@ wtap_encaps = {
 	["MA_WFP_CAPTURE_AUTH_V4"] = 195,
 	["MA_WFP_CAPTURE_AUTH_V6"] = 196,
 	["JUNIPER_ST"] = 197,
-	["ETHERNET_MPACKET"] = 198
+	["ETHERNET_MPACKET"] = 198,
+	["DOCSIS31_XRA31"] = 199
 }
 wtap = wtap_encaps -- for bw compatibility
 
